# shade.r
# Time-stamp: <07 Nov 2012 09:44:57 c:/x/rpack/corrgram/tests/shade.r>

mat <- matrix(c(
0,-0.0063557,-0.52034,0.17974,-0.090269,0,0,3,1,1,
1,-0.66534,-0.078071,-0.2425,-0.2776,1,0,4,1,1,
1,0.03836,-0.24474,0.070106,0.044389,1,0,6,1,1,
1,0.4645,0.0043093,0.65541,0.17996,1,0,9,1,1,
1,0.62656,-0.51019,0.22007,-0.051537,1,1,10,1,1,
0,-0.92401,-0.11931,-0.72242,-0.64402,1,0,12,1,1,
1,-0.55785,0.73992,0.12407,0.23778,0,1,13,2,1,
0,-0.030955,0.61578,0.1019,0.0093832,0,1,19,2,1,
1,1.0735,1.3633,1.5073,0.7068,1,0,20,2,1,
0,-1.4062,-0.99769,-1.0556,-1.1166,0,1,21,2,1,
1,1.0821,0.62027,0.40839,0.38328,1,1,22,2,1,
1,-1.0223,-0.18608,-0.93797,-0.58853,1,0,23,2,1,
0,-0.56094,0.21872,-0.30374,-0.27042,0,1,24,2,1,
0,-0.75308,-0.22137,-0.31962,-0.27659,0,0,25,3,1,
1,-1.3207,-0.57955,-0.84339,-0.69981,1,0,26,3,1,
1,0.52338,0.22154,0.39105,0.65214,1,1,28,3,1,
0,-0.28912,0.47837,0.056063,-0.013337,0,0,29,3,1,
0,0.21723,-0.4584,0.01483,-0.36337,1,1,30,3,1,
0,-0.74584,-0.18726,-0.40159,-0.24562,0,0,31,3,1,
0,-0.39739,0.36549,-0.28682,-0.13004,0,1,33,3,1,
1,-0.071139,0.81738,0.28133,0.30643,0,1,34,3,1,
1,0.65857,-0.0083105,0.012263,0.028136,1,1,35,3,1,
0,0.75373,1.1012,1.2978,0.63162,1,0,36,3,1,
0,0.15019,0.039047,0.097294,0.11139,1,1,37,4,1,
1,0.29455,0.62134,0.47873,0.49896,1,0,38,4,1,
1,0.26025,0.93127,0.28043,0.23816,0,1,39,4,1,
0,0.19347,1.2005,0.68489,0.55068,1,0,40,4,1,
0,-0.93518,-0.43188,-0.044631,0.096922,1,0,41,4,1,
1,0.14502,-0.036376,0.016692,-0.03667,0,0,42,4,1,
1,-0.38678,0.20155,-0.43132,0.1209,1,1,43,4,1,
1,-0.66882,0.11855,-0.99761,-0.33738,0,1,44,4,1,
1,-0.30013,0.7149,0.40989,0.16103,0,0,45,4,1,
0,-0.47594,-0.071069,-0.29139,-0.44721,1,0,46,4,1,
1,-0.38494,0.11604,-0.17073,-0.31089,0,0,47,4,1,
0,-0.58323,0.74486,0.039873,-0.19283,0,1,48,4,1,
1,0.011614,-0.12362,-0.1276,0.05365,0,1,1,1,2,
0,-0.45942,0.13049,0.10467,-0.047419,0,1,2,1,2,
1,0.11962,0.1694,0.16908,-0.10694,0,1,4,1,2,
1,0.23463,0.22685,0.14601,0.061082,0,1,5,1,2,
0,-0.63964,-0.28306,-0.26033,-0.35497,1,0,6,1,2,
1,0.1109,0.31011,0.20598,0.16523,0,1,7,1,2,
1,0.22597,-0.16719,0.21097,-0.093295,1,1,8,1,2,
1,0.21119,0.11408,0.23723,0.22725,1,0,9,1,2,
0,0.061003,0.038496,0.031612,-0.094042,0,1,10,1,2,
1,0.335,0.25682,0.2008,0.075898,1,1,11,1,2,
1,0.52617,0.21393,0.21018,0.13185,1,1,12,1,2,
1,0.14642,-0.15833,-0.22388,-0.13157,0,1,13,2,2,
1,-0.20886,-0.13654,-0.2517,-0.32142,1,1,14,2,2,
0,-0.17014,0.072338,0.24326,0.23941,1,0,15,2,2,
0,0.26606,0.028054,0.086822,0.088357,0,0,16,2,2,
1,-0.067843,0.09918,0.095714,0.18589,0,1,18,2,2,
1,-0.16432,-0.1481,-0.17136,-0.1495,0,1,19,2,2,
1,0.6434,0.45838,0.40384,0.16381,0,1,21,2,2,
0,0.12073,0.025097,-0.035612,0.16496,1,1,22,2,2,
1,-0.14962,0.011726,0.13713,-0.0804,0,0,23,2,2,
1,-0.56032,-0.019857,-0.20665,-0.22915,1,0,24,2,2,
1,0.37768,0.10652,0.10134,0.08569,1,1,26,3,2,
1,0.45484,0.1108,0.13917,0.19982,0,0,27,3,2,
0,-0.022518,-0.048881,-0.16093,-0.16938,1,0,28,3,2,
1,0.088624,0.30242,0.47275,0.39068,0,0,29,3,2,
1,-0.068328,-0.10077,0.073642,-0.064742,0,0,30,3,2,
1,0.31682,0.099152,0.08226,0.2744,0,1,32,3,2,
1,0.42303,0.11037,-0.02043,-0.15647,1,1,33,3,2,
0,-0.34082,-0.053895,0.36643,0.25137,0,0,34,3,2,
0,0.094773,0.44576,0.074021,-0.053694,1,0,36,3,2,
1,0.38238,0.11652,0.011054,-0.012712,0,1,37,4,2,
1,-0.3418,0.11756,0.094365,-0.069955,0,1,38,4,2,
0,-0.50942,0.0050952,0.22966,0.1996,1,0,39,4,2,
1,0.91369,0.31662,0.45777,0.38404,0,0,40,4,2,
1,0.68338,-0.63064,0.11742,0.13487,1,1,41,4,2,
0,-0.14964,-0.076256,-0.023992,-0.10177,1,0,42,4,2,
1,0.054243,0.57133,0.55027,0.29552,0,1,43,4,2,
1,0.15717,0.057871,-0.1868,0.0025904,1,1,44,4,2,
1,0.38316,0.16829,0.14001,0.18288,0,1,45,4,2,
1,0.34977,-0.19306,0.23014,-0.0027275,1,0,46,4,2,
1,0.3938,0.2889,0.19991,0.25546,0,1,47,4,2,
1,0.75616,0.13566,0.20901,0.1666,1,1,48,4,2,
1,0.047865,0.13474,0.034456,0.029411,0,1,1,1,3,
0,0.19856,0.19151,0.21901,-0.090367,1,0,2,1,3,
1,-0.37712,0.24742,0.16589,-0.19674,0,1,3,1,3,
1,0.29536,0.23929,0.081114,-0.046252,0,1,4,1,3,
0,-0.56006,0.042819,0.12521,0.085943,1,0,5,1,3,
1,-0.30896,0.42771,-0.14428,-0.33308,0,1,6,1,3,
1,-0.54948,-0.091838,-0.34569,-0.16267,1,0,7,1,3,
0,-0.53557,0.10264,0.12384,-0.27998,0,0,8,1,3,
0,0.16911,0.25264,0.31849,0.31347,1,0,9,1,3,
0,-0.3707,-0.12115,-0.22481,-0.40798,0,1,10,1,3,
1,-0.075231,0.15457,0.029948,-0.040105,1,0,11,1,3,
1,-0.45663,-0.18699,-0.33821,-0.37072,1,0,12,1,3,
0,0.26847,-0.017131,0.078879,0.10872,1,1,13,2,3,
1,0.18023,0.34396,0.31504,-0.02324,0,1,14,2,3,
0,-0.65179,-0.26352,-0.22559,-0.21231,1,0,15,2,3,
0,-0.21313,0.098999,0.080437,-0.3949,0,1,17,2,3,
0,-0.41373,-0.00018519,-0.079866,-0.2205,0,1,18,2,3,
1,-0.033911,-0.090095,-0.061926,-0.22321,1,1,19,2,3,
0,-0.4055,0.46437,0.5833,-0.069374,0,0,20,2,3,
1,-0.43907,-0.051803,-0.061136,-0.3676,1,0,22,2,3,
0,-0.60902,0.29403,0.17562,-0.486,0,1,23,2,3,
0,-0.48666,-0.16289,-0.29745,-0.4833,0,1,24,2,3,
0,-0.070214,0.0010364,-0.12239,-0.022531,0,1,25,3,3,
0,-0.37895,-0.10641,-0.13778,-0.31267,1,0,26,3,3,
1,-0.5175,-0.11354,0.17507,-0.28744,1,0,27,3,3,
0,0.40861,0.20555,0.13923,0.079267,0,0,28,3,3,
1,-0.39044,0.57253,0.12542,0.064586,0,1,29,3,3,
1,0.024892,-0.045542,-0.0044135,-0.077888,1,1,30,3,3,
0,0.057844,-0.10173,-0.04102,-0.36736,1,1,34,3,3,
0,0.19672,0.024429,0.14726,0.23452,1,1,37,4,3,
0,0.0046327,0.36905,0.37844,0.63592,1,0,38,4,3,
0,-1.0094,0.011608,-0.7508,-0.24252,0,1,41,4,3,
0,-0.4903,0.41061,0.092121,0.014982,0,1,43,4,3,
0,-0.64315,0.033943,-0.15161,-0.3166,0,0,44,4,3,
0,0.74126,0.5084,0.76195,0.4619,0,0,48,4,3,
0,-0.0040611,-0.064103,-0.042898,-0.021151,0,0,1,1,4,
0,-0.4947,-0.2861,-0.41461,-0.3903,1,0,2,1,4,
0,-0.50964,-0.057672,-0.056861,-0.14608,0,0,3,1,4,
0,-0.49341,-0.81266,-0.22677,-0.39328,0,0,4,1,4,
1,-0.26754,-0.25289,-0.33036,-0.33545,1,1,5,1,4,
1,0.72186,-0.41007,-0.28235,-0.10603,1,1,6,1,4,
0,-0.29303,-0.48752,0.57789,-0.31088,1,0,8,1,4,
1,0.12038,-0.38033,-0.034184,-0.22961,1,1,9,1,4,
0,-0.29472,-0.20188,0.21388,-0.12888,0,0,10,1,4,
0,0.0075273,0.090796,0.2555,0.18959,0,0,13,2,4,
1,-0.1415,0.24477,-0.27526,0.016029,0,1,21,2,4,
0,-0.34223,-0.25433,-0.42294,-0.19931,1,1,23,2,4,
1,0.064508,-0.14073,-0.27364,-0.075319,1,1,25,3,4,
1,0.39448,0.21778,0.031846,0.22626,0,1,26,3,4,
1,-0.4014,-0.097654,-0.0015485,-0.22602,0,0,27,3,4,
0,0.14811,-0.19491,0.25853,-0.096393,1,0,28,3,4,
1,0.55636,-0.081755,-0.19565,0.023498,0,1,29,3,4,
0,-0.087194,-0.024223,-0.15492,-0.11975,1,0,30,3,4,
0,-0.35263,-0.38023,0.26427,-0.035966,0,0,31,3,4,
1,0.13412,-0.58533,-0.36322,-0.56561,1,1,32,3,4,
0,-0.085663,0.11378,-0.20018,0.016454,1,0,33,3,4,
0,0.13047,-0.016585,0.15167,0.082155,0,0,34,3,4,
1,-0.12316,-0.0043656,-0.60258,-0.21977,1,1,36,3,4,
0,0.22281,0.17744,0.10981,0.30438,0,1,37,4,4,
0,-0.58398,-0.49816,-0.61723,-0.42981,0,1,38,4,4,
0,0.11392,0.221,-0.13571,0.19503,1,0,39,4,4,
0,-0.36266,-0.17389,-0.073085,-0.25578,1,0,40,4,4,
0,-0.68294,-0.58962,-0.028536,-0.60029,0,0,41,4,4,
0,0.29616,-0.19599,0.76784,0.50282,1,0,43,4,4,
0,-0.052891,-0.21472,0.16393,0.037241,0,0,44,4,4,
0,0.16133,-0.041995,1.0843,0.34457,0,0,45,4,4,
0,-0.42175,-0.2457,-0.32354,-0.19986,1,0,46,4,4,
0,0.041789,-0.24084,0.17691,0.063093,1,0,47,4,4,
0,0.1341,0.46346,0.010834,0.0081875,0,1,1,1,5,
0,1.0629,0.89458,0.99628,0.68603,1,1,2,1,5,
0,0.0367,0.63969,-0.31218,-0.080217,0,1,3,1,5,
0,-0.86064,-0.30877,-0.40574,-0.23849,0,1,4,1,5,
0,0.67693,0.059844,0.65788,0.41883,1,1,5,1,5,
0,0.021917,-0.78316,-0.25051,-0.21665,1,1,6,1,5,
0,0.061031,1.4452,0.44571,0.33003,0,1,7,1,5,
0,0.020353,0.10171,0.24244,0.024417,1,0,8,1,5,
0,0.65794,0.5765,-0.18119,-0.069069,0,1,9,1,5,
0,0.080912,0.063021,0.18838,-0.013591,1,0,10,1,5,
0,0.36447,0.48694,0.090122,-0.055974,0,1,11,1,5,
0,-0.094714,0.076403,0.020039,-0.048686,0,0,13,2,5,
0,-0.45116,0.1391,-0.56529,-0.17662,1,1,14,2,5,
0,-0.88525,0.43729,0.23479,-0.22486,0,1,15,2,5,
0,-0.21415,0.34779,0.075543,-0.13243,0,1,16,2,5,
0,0.50899,-0.77624,-0.50574,-0.15374,1,1,17,2,5,
0,-0.79835,0.78186,0.65694,0.14956,1,0,18,2,5,
0,-0.46746,0.52994,-0.25385,-0.048695,0,1,19,2,5,
0,0.60348,0.71361,0.37286,0.25456,1,1,20,2,5,
0,-1.7038,-1.1318,-1.3297,-0.8643,1,0,22,2,5,
0,0.78882,-0.41671,-0.21366,0.17823,1,1,24,2,5,
0,0.28681,0.10724,0.21452,0.17472,1,1,25,3,5,
0,-0.04506,1.5563,0.92662,0.28674,0,1,26,3,5,
0,-1.4624,1.0969,0.51616,0.12689,0,1,28,3,5,
0,-0.22995,0.72336,0.18991,0.15309,1,0,30,3,5,
0,0.34629,0.63679,0.044562,0.026672,0,1,31,3,5,
0,0.16276,-0.1769,-0.19227,-0.010182,1,1,32,3,5,
0,0.51189,1.4049,0.73984,0.38476,0,1,33,3,5,
0,0.72964,-0.2582,0.42755,0.31459,1,1,34,3,5,
0,-1.0217,1.3493,0.60359,0.16368,0,1,35,3,5,
0,0.52636,0.6511,-0.24308,0.27948,0,1,36,3,5,
0,-0.015205,0.46279,0.22654,0.074865,0,0,37,4,5,
0,-0.32408,1.0471,0.41522,0.37922,1,0,39,4,5,
0,-0.77652,0.50018,-0.20976,-0.20249,0,1,41,4,5,
0,-0.3455,-0.37762,-0.086111,-0.17832,1,0,42,4,5,
0,0.20262,0.6271,-0.19878,-0.069044,0,1,43,4,5,
0,0.37249,1.5835,0.63469,0.32254,0,1,46,4,5,
0,0.66938,-0.57174,-0.16793,-0.11871,1,1,48,4,5,
0,-0.26436,-0.20737,0.19249,0.042862,0,0,2,1,6,
1,0.85349,1.4071,0.4692,0.37456,1,1,4,1,6,
0,-0.051214,1.7915,1.3778,0.81393,0,1,5,1,6,
1,0.48935,0.36587,0.14401,0.00046097,0,1,7,1,6,
1,-1.2529,-1.1452,-0.75656,-0.53977,0,0,9,1,6,
1,0.89723,-1.0516,0.68674,0.0078522,1,1,14,2,6,
1,-0.52942,0.026184,0.14698,0.012774,0,0,15,2,6,
0,1.1489,-1.7537,-0.11281,0.040445,1,1,16,2,6,
0,-0.055349,0.53838,0.45898,0.48081,0,1,22,2,6,
0,0.51466,0.65218,0.64157,0.35864,0,1,23,2,6,
0,0.39468,-0.24497,0.0060071,-0.18034,0,0,25,3,6,
0,0.091001,0.13062,0.10864,0.26877,0,1,28,3,6,
1,-1.0203,-0.52837,-0.57133,-0.41686,1,0,29,3,6,
1,-0.17801,0.2409,-0.063222,0.021927,0,1,31,3,6,
0,-0.11415,-1.7273,-0.50008,-0.3728,0,0,34,3,6,
1,1.2098,0.94194,0.50066,0.51833,1,1,35,3,6,
0,-0.34271,-0.23758,-0.12901,-0.14876,1,0,37,4,6,
0,-0.45404,-3.3927,-0.86817,-0.20647,1,0,44,4,6,
0,-0.16435,-0.56622,0.02726,-0.45476,0,0,45,4,6,
0,0.45702,1.3423,-0.016154,0.23475,0,1,46,4,6,
0,0.28051,0.37883,-0.032525,0.24856,0,1,1,1,7,
1,-0.30419,-0.025296,0.10634,0.049663,0,0,2,1,7,
1,-0.11319,-1.0217,-0.40375,-0.65463,1,1,3,1,7,
1,0.54573,0.32491,0.018455,0.23832,0,1,4,1,7,
0,0.39794,0.25339,0.22107,0.51136,1,1,5,1,7,
0,-0.14137,-0.21154,-0.16279,-0.30807,1,1,6,1,7,
1,-0.00056298,-0.15774,0.082449,0.10579,0,0,7,1,7,
0,-0.21241,-1.1075,-0.41892,-0.65483,0,0,8,1,7,
1,0.62999,-0.0939,-0.0023002,0.078934,1,1,9,1,7,
1,0.34506,0.2651,0.31434,0.16141,1,1,10,1,7,
0,-0.1307,-0.089112,-0.44398,-0.33841,0,1,11,1,7,
0,-0.10365,-0.069529,-0.0040124,0.069552,1,0,12,1,7,
1,-0.19269,-0.037847,-0.20974,-0.006178,0,1,13,2,7,
1,-0.79852,0.085957,0.12315,0.22266,1,0,14,2,7,
0,0.25642,-0.060329,0.096909,0.033832,0,0,15,2,7,
0,0.21566,0.17574,0.18024,0.28901,1,1,16,2,7,
1,0.10543,0.46013,0.10253,0.26234,0,1,17,2,7,
1,0.22528,0.48729,-0.097136,0.56992,0,1,18,2,7,
1,0.65248,0.56948,-0.054744,0.43167,1,1,19,2,7,
0,0.99592,0.072108,-0.05227,0.17615,1,1,20,2,7,
1,0.083321,-0.057664,-0.20274,0.24028,0,1,21,2,7,
1,0.93473,0.60032,0.23308,0.40372,1,1,22,2,7,
1,0.40827,0.021228,-0.074397,0.28321,1,0,23,2,7,
1,0.36146,-0.43285,-0.12929,-0.076833,0,0,24,2,7,
1,0.077635,-0.20798,0.03547,-0.045434,1,0,25,3,7,
1,0.33217,0.14439,-0.01389,0.17761,0,0,26,3,7,
1,0.38924,-0.3395,0.013378,-0.13799,1,1,27,3,7,
1,-0.032006,-0.057672,0.1351,-0.063364,0,0,28,3,7,
1,0.28631,0.17023,0.18637,-0.05599,0,0,29,3,7,
0,0.94032,0.29513,0.14948,0.30442,1,1,30,3,7,
1,0.027313,-0.19831,-0.0037087,-0.044982,1,0,31,3,7,
1,-0.27344,-0.52136,-0.34941,-0.40164,0,0,32,3,7,
1,1.5621,0.071468,0.087561,0.53724,1,1,33,3,7,
0,-0.29484,0.26641,-0.15543,0.12849,0,1,34,3,7,
1,0.4142,0.63,0.29854,0.4305,0,1,35,3,7,
1,-0.030231,0.10317,0.26282,0.26345,1,0,36,3,7,
1,-0.013773,-0.0529,-0.12687,0.054775,1,0,37,4,7,
1,0.47367,-0.10043,0.25886,0.078348,1,0,38,4,7,
1,0.21731,0.10606,0.069212,0.1127,0,0,39,4,7,
1,-0.26949,0.19035,0.43981,0.097262,1,0,40,4,7,
0,-0.27543,0.38275,0.2696,0.085875,0,0,41,4,7,
0,-0.10185,-0.22573,-0.056283,-0.016107,0,0,42,4,7,
0,0.32574,-0.0037271,0.063899,-0.049353,1,0,43,4,7,
0,0.36191,-0.39691,-0.34883,-0.26188,0,0,44,4,7,
0,0.30132,-0.34842,0.18544,-0.054477,1,0,45,4,7,
0,-0.2435,-1.4206,-0.64626,-0.86248,0,0,46,4,7,
0,-0.1173,-0.17808,0.051173,-0.19225,1,0,47,4,7,
0,0.028524,-0.30239,-0.28016,-0.11414,0,0,48,4,7,
0,-0.083722,-0.058343,-0.087916,-0.10619,1,0,1,1,8,
1,-0.80923,-0.1473,-0.60944,-0.12553,0,1,2,1,8,
1,-0.72432,0.095042,-0.42623,-0.19387,0,1,3,1,8,
1,-0.59068,-0.15667,-0.3523,-0.33544,1,0,4,1,8,
1,0.68986,0.31544,0.18792,0.38405,0,1,5,1,8,
1,-0.29281,-0.052596,0.062359,-0.20617,1,0,6,1,8,
1,0.11936,-0.2948,0.23075,0.12318,1,0,7,1,8,
1,-0.24437,0.28752,-0.08431,0.10395,0,1,9,1,8,
1,-0.13191,-0.42711,0.050033,-0.27418,1,0,10,1,8,
1,-0.10436,-0.0063187,0.065235,-0.16198,1,0,11,1,8,
0,-0.52911,0.29489,0.14987,0.32862,0,1,12,1,8,
0,0.1871,0.027397,0.12602,0.029611,1,1,13,2,8,
1,-0.43944,0.26091,0.080355,0.18272,0,1,14,2,8,
0,-0.23351,0.25303,0.21519,0.2137,0,0,15,2,8,
0,-0.074671,-0.059483,0.093837,-0.0097646,1,0,16,2,8,
1,-0.14786,-0.18142,-0.21602,0.0057689,1,1,18,2,8,
0,-0.90891,-0.37597,0.014903,-0.23827,1,0,19,2,8,
0,-0.029572,-0.085282,-0.24139,-0.15838,1,1,22,2,8,
0,-0.54736,0.1115,-0.24743,0.071188,0,1,23,2,8,
0,-0.85683,-0.32505,-0.18718,-0.24078,1,0,24,2,8,
0,-0.1977,-0.0084375,0.11809,-0.051902,0,0,25,3,8,
0,0.24284,0.35257,0.22451,0.51981,1,1,26,3,8,
1,-0.44741,0.077673,0.02393,0.089601,0,0,27,3,8,
1,-0.55508,-0.29731,0.17409,-0.16101,1,0,28,3,8,
0,-0.99654,-0.78027,-0.87543,-0.72748,1,0,30,3,8,
1,-0.07891,-0.53571,0.18898,-0.28218,1,0,31,3,8,
1,0.56119,0.12833,0.077482,0.23973,0,0,32,3,8,
0,-0.11941,0.068841,0.0034314,0.13432,0,0,34,3,8,
0,0.85803,-0.10392,0.13482,0.062141,0,0,36,3,8,
0,-0.2359,-0.1069,-0.21928,-0.17135,0,0,37,4,8,
0,-0.37328,0.097509,0.0037435,-0.35976,1,0,41,4,8,
0,0.11027,0.021696,0.039378,0.12919,1,1,44,4,8,
1,0.18318,0.45163,0.48091,0.45065,0,0,45,4,8,
1,-0.51537,-0.16945,-0.21535,-0.43173,1,0,46,4,8,
0,0.39559,0.09479,0.25169,0.24842,1,1,47,4,8,
1,0.13926,0.63371,0.14007,0.20234,0,1,1,1,9,
0,-0.18323,0.3727,0.36371,0.11989,1,0,2,1,9,
0,0.093141,0.90646,-0.03407,0.18694,0,1,3,1,9,
0,-0.21767,0.13227,0.22827,0.061099,0,0,4,1,9,
0,-0.57291,-0.21684,0.054736,-0.029589,1,0,6,1,9,
1,-0.45157,0.59813,0.17875,0.20467,0,1,7,1,9,
1,-0.46546,0.7686,0.09394,0.23922,1,0,8,1,9,
0,-0.26585,0.027525,0.081618,-0.19968,1,0,10,1,9,
0,-0.53797,-1.063,-0.012588,-0.28489,0,0,12,1,9,
1,0.22878,1.017,0.1497,0.44414,1,1,13,2,9,
0,-0.42546,-0.28185,-0.105,-0.032564,1,0,14,2,9,
0,0.0703,0.14481,0.025103,0.017653,1,1,17,2,9,
0,-0.66858,0.7715,0.74284,0.29658,0,1,18,2,9,
0,-0.63418,0.045271,0.012813,-0.029566,0,1,19,2,9,
0,-0.3146,-0.43484,0.39048,-0.011641,0,0,21,2,9,
1,0.088546,0.5614,0.073599,0.27103,1,1,22,2,9,
1,-0.95593,-0.23295,0.053058,-0.088489,0,0,23,2,9,
0,-0.026434,0.10582,-0.0023965,0.18498,0,1,24,2,9,
1,-0.076975,0.35821,0.061489,0.039315,0,1,25,3,9,
0,0.17428,0.99438,-0.14689,0.59567,0,1,26,3,9,
0,0.11905,0.7604,0.2644,0.41501,1,0,27,3,9,
1,-0.27168,-0.31519,-0.28682,-0.18464,1,1,30,3,9,
0,-0.22419,1.5035,0.66783,0.53275,0,1,31,3,9,
1,-0.15504,-0.6204,-0.33338,-0.13673,1,1,32,3,9,
0,-0.15656,-0.45936,0.027727,-0.11399,1,0,35,3,9,
1,0.30108,-0.16946,-0.10747,-0.081587,1,1,37,4,9,
1,-0.12415,0.13562,0.37152,0.12516,0,0,38,4,9,
1,-0.34952,0.5746,-0.0098883,0.27274,0,1,39,4,9,
1,-0.28676,-0.79181,-0.31405,-0.21316,1,1,40,4,9,
0,-0.42775,-1.008,-0.12998,-0.38639,1,0,41,4,9,
0,0.35371,0.22508,-0.059669,0.14829,0,0,42,4,9,
1,-0.34226,0.87003,0.15814,0.21532,0,1,43,4,9,
1,0.21041,0.49518,0.13931,0.13578,1,0,44,4,9,
0,0.023988,0.0047355,0.32011,-0.033792,1,0,45,4,9,
0,-0.28803,-0.23306,-0.23835,0.052917,1,0,48,4,9,
0,0.020611,0.099675,-0.056474,-0.043156,1,1,1,1,10,
1,-0.73034,-0.36391,-0.40266,-0.4564,0,1,2,1,10,
0,-0.052071,0.46347,0.115,0.18109,0,1,3,1,10,
1,-0.44062,0.25967,-0.49462,-0.29602,1,1,4,1,10,
0,-0.11139,0.44768,0.33699,0.21507,0,1,5,1,10,
1,-0.32524,-0.011874,0.15316,0.057984,1,0,6,1,10,
0,0.35811,0.69897,0.013156,0.20906,0,1,7,1,10,
0,-0.55898,-0.42396,0.050196,-0.055518,1,0,8,1,10,
1,0.62388,0.28225,-0.15701,0.076969,0,1,9,1,10,
1,0.31872,0.29914,0.11093,0.21388,1,1,10,1,10,
1,0.059228,0.60505,0.30755,0.23676,0,1,11,1,10,
1,0.33587,0.4159,0.28478,0.3128,1,1,12,1,10,
1,-0.18254,0.12136,0.16186,0.042801,0,0,13,2,10,
1,-1.8105,-0.31462,0.041877,-0.37065,0,0,14,2,10,
1,0.21347,0.38206,0.35617,0.064483,1,0,15,2,10,
1,0.54415,0.97044,0.30542,0.6024,0,1,16,2,10,
1,0.36798,0.66745,0.23851,0.11965,1,1,17,2,10,
1,1.1599,0.70044,0.42226,0.28709,1,1,18,2,10,
0,-0.20216,-0.41781,-0.0068796,0.11431,0,0,19,2,10,
0,-0.49949,-0.21697,0.11232,-0.024232,1,0,20,2,10,
1,0.99263,0.90546,0.41202,0.61854,0,1,21,2,10,
1,-1.115,0.75755,0.38009,0.020791,0,1,22,2,10,
0,-0.59935,0.2847,0.33157,-0.042522,1,0,23,2,10,
0,0.21066,0.57723,0.46484,0.18789,1,0,24,2,10,
0,-0.33147,-0.19795,0.0048255,-0.081479,1,0,25,3,10,
0,-0.44286,0.0073649,0.3184,-0.18414,1,0,26,3,10,
0,0.31931,0.31567,0.68359,0.30272,0,0,27,3,10,
1,0.22397,0.14123,-0.13407,-0.040277,1,1,28,3,10,
0,-0.035648,1.0595,0.56503,0.25266,0,1,29,3,10,
0,0.63878,0.4389,-0.034441,-0.017419,0,1,30,3,10,
1,1.1553,1.3853,0.46038,0.54278,1,1,31,3,10,
0,0.5715,1.1224,0.37015,0.46156,0,1,32,3,10,
0,0.87109,0.96779,0.3374,0.43381,1,1,33,3,10,
1,0.60216,1.1107,0.36377,0.37143,0,1,34,3,10,
1,1.1929,0.89999,0.2996,0.31964,1,1,35,3,10,
1,-0.2912,1.8864,0.64812,0.44812,0,1,36,3,10,
1,-0.61239,-0.039183,0.10955,0.036617,1,0,37,4,10,
1,-0.22493,-0.1798,0.27089,-0.15782,1,0,38,4,10,
0,0.0038313,0.21,0.46628,0.32487,0,0,39,4,10,
0,-0.23312,0.3561,0.67987,0.026209,0,0,40,4,10,
0,-0.073647,0.19014,0.5007,0.021197,1,0,41,4,10,
0,0.24374,0.29643,0.32056,0.07683,0,0,42,4,10,
0,-1.2002,-0.55004,0.28189,-0.13854,0,0,43,4,10,
0,0.015377,0.46672,0.15161,-0.023941,1,0,44,4,10,
0,0.1597,0.115,0.42309,0.10113,0,0,45,4,10,
0,1.1886,0.24699,0.32441,0.28559,1,1,46,4,10,
1,0.66832,0.81242,0.34751,0.26421,1,1,47,4,10,
1,0.2818,0.6055,0.078175,0.39415,0,1,48,4,10,
1,-0.28823,0.35055,-0.082437,0.026158,1,0,1,1,11,
1,0.22455,0.15425,0.023108,0.095343,0,1,3,1,11,
1,0.6545,1.6705,0.52832,0.22758,1,1,4,1,11,
0,0.87448,1.1561,0.62051,0.46986,0,1,5,1,11,
0,-0.38533,0.23796,0.20873,0.0038048,1,0,6,1,11,
1,-0.61379,0.79303,-0.010576,0.021566,1,0,9,1,11,
1,-0.48888,-1.834,-0.13406,-0.18551,0,0,10,1,11,
1,-0.18887,0.52163,-0.079585,0.058972,0,1,13,2,11,
0,-0.04268,1.2796,0.54447,0.34408,0,1,14,2,11,
1,0.67859,1.3084,0.51067,0.41533,1,1,15,2,11,
0,0.1393,0.96131,0.33003,0.25953,1,0,16,2,11,
1,0.18172,1.1139,0.40968,0.21759,0,1,17,2,11,
1,0.61687,1.0962,0.21744,0.31619,1,1,18,2,11,
0,-0.14211,-1.6697,-0.17062,-0.024398,1,1,20,2,11,
0,-0.38088,0.38202,0.32153,-0.081832,0,0,21,2,11,
1,0.61826,0.56511,-0.042192,0.32685,1,1,24,2,11,
1,-0.13415,0.44526,0.062345,0.015342,1,0,25,3,11,
1,-0.058292,-1.1468,-0.062332,-0.1004,0,0,26,3,11,
1,-0.14758,0.24422,-0.030012,0.066503,1,0,31,3,11,
0,0.00068438,-2.2019,-0.43432,-0.28094,1,1,33,3,11,
0,-0.14813,0.39243,0.28684,0.063043,0,0,35,3,11,
0,-0.44504,0.16236,0.01398,0.025124,1,0,36,3,11,
1,-0.11981,-1.8278,-0.091638,-0.067312,1,0,39,4,11,
1,0.080024,0.9413,0.037022,0.2181,0,1,41,4,11,
0,0.02124,-0.34244,-0.16383,-0.022763,1,0,42,4,11,
0,-0.22601,-0.38461,-0.28338,-0.22028,1,0,43,4,11,
0,0.33225,1.23,0.43339,0.29451,0,1,44,4,11,
0,0.53327,-0.33129,0.075841,0.14119,1,1,45,4,11,
1,0.16526,1.0944,0.27245,-0.023414,0,1,46,4,11,
1,0.20748,-0.2029,0.21111,0.080984,0,0,47,4,11,
0,-0.46129,0.060139,0.014954,-0.10133,1,0,48,4,11,
0,0.23457,0.50166,0.21186,0.26462,0,1,1,1,12,
1,-0.18529,0.20317,0.23772,-0.066568,0,0,2,1,12,
1,-0.015537,0.36536,0.14647,0.044979,1,0,3,1,12,
1,0.23768,0.70924,0.37165,0.28967,1,0,4,1,12,
1,0.097185,0.36404,0.35412,-0.040835,0,0,5,1,12,
1,-0.24873,0.22552,0.22592,0.015667,0,0,6,1,12,
1,-0.35324,0.064068,0.011688,-0.15104,1,0,7,1,12,
1,0.0026813,0.22009,0.25563,-0.072869,1,0,8,1,12,
0,0.24177,0.5958,0.40375,0.3461,0,1,9,1,12,
1,-0.47082,-0.6284,-1.1461,-0.59373,1,1,11,1,12,
1,-0.2533,0.073938,0.16151,-0.090933,1,0,12,1,12,
1,0.0882,0.12676,-0.049093,0.062309,1,1,13,2,12,
1,-0.42332,-0.054378,-0.21947,-0.28827,0,1,14,2,12,
0,1.1009,1.3889,0.73273,0.71861,1,1,15,2,12,
1,-0.59346,-0.49341,-0.25596,-0.54692,1,0,16,2,12,
0,0.44654,0.39019,0.27202,0.12235,0,1,17,2,12,
1,0.41463,0.31157,0.27834,0.052173,0,1,18,2,12,
1,0.17768,0.134,0.1532,0.16555,1,1,19,2,12,
1,-0.019411,0.33761,0.14984,-0.13142,1,0,21,2,12,
0,-0.4864,-0.42594,0.020936,-0.15657,1,0,22,2,12,
1,-0.1467,0.20542,0.11241,-0.2931,0,0,23,2,12,
0,-1.3425,-1.7807,-1.0024,-1.7633,0,0,24,2,12,
1,-0.0097328,0.015199,0.011932,0.036967,0,0,25,3,12,
1,0.066037,0.19746,0.24673,0.034045,1,0,26,3,12,
1,0.54581,0.22914,0.18095,0.00024179,1,1,27,3,12,
1,-0.051854,0.402,0.27789,-0.21506,0,0,28,3,12,
0,0.34967,-0.047245,-0.054542,0.13077,1,1,29,3,12,
0,-0.29494,0.24827,0.033927,-0.29994,0,1,30,3,12,
1,-0.38428,-0.037983,-0.21879,-0.28069,1,0,31,3,12,
1,0.19319,0.38127,0.1949,-0.25845,0,0,32,3,12,
1,-0.29992,-0.57218,-0.35225,-0.60305,1,1,33,3,12,
0,-0.24264,-0.36653,-0.067067,-0.81192,0,0,34,3,12,
1,0.017548,-0.14184,-0.20679,-0.55495,0,0,35,3,12,
1,-0.67253,-0.30634,-0.22857,-0.43341,1,0,36,3,12,
1,-0.083328,0.019286,-0.23606,-0.086727,1,1,37,4,12,
1,-0.38175,-0.50275,-0.45358,-0.41281,1,1,38,4,12,
0,0.034486,0.077831,-0.043855,0.10499,0,0,39,4,12,
1,-0.17028,-0.020576,0.078671,-0.39454,0,0,40,4,12,
1,-0.46352,-0.12494,-0.11741,-0.271,1,0,41,4,12,
1,0.89646,0.36806,0.149,0.33073,0,1,42,4,12,
0,-1.0196,-1.8216,-0.9352,-1.4628,1,0,43,4,12,
0,-0.24879,0.48534,0.10554,0.22265,0,1,44,4,12,
1,0.25831,0.70944,0.43637,0.28228,1,0,45,4,12,
1,-0.65706,-0.22594,-0.50065,-0.29988,0,1,46,4,12,
1,-0.034366,-0.12616,-0.14439,-0.15072,1,1,47,4,12,
0,0.19007,-0.37233,-0.21839,-0.15946,0,0,48,4,12,
1,0.18674,0.089609,0.2729,0.1047,0,0,1,1,13,
0,-0.25908,0.13242,-0.48149,-0.41694,0,1,2,1,13,
0,-0.33496,-0.22606,-0.15888,-0.093338,1,0,3,1,13,
0,0.26954,0.12947,-0.076695,-0.035239,0,1,4,1,13,
0,-0.30725,0.10699,-0.54713,-0.087041,0,1,7,1,13,
1,0.44738,-0.065387,0.026634,0.16876,1,1,9,1,13,
1,0.066264,0.66806,0.20583,0.06176,0,1,11,1,13,
0,-0.0733,-0.088035,0.21995,0.21843,1,0,12,1,13,
1,0.16409,0.17009,0.19285,0.32577,0,0,13,2,13,
0,0.0029541,0.085479,-0.79371,-0.4146,1,1,14,2,13,
1,-0.9051,-0.18433,-0.91584,-0.6328,0,1,15,2,13,
1,-1.2535,-0.40965,-2.043,-1.1229,1,1,16,2,13,
0,-0.54716,-0.40944,-0.57624,0.02989,0,1,17,2,13,
0,0.71097,0.20789,0.3101,0.20171,1,1,18,2,13,
1,0.22172,0.24428,-0.76982,-0.14895,0,1,20,2,13,
0,0.54572,0.6185,-0.30967,0.26184,0,1,23,2,13,
1,0.11234,0.062848,0.23845,0.18548,1,0,24,2,13,
0,0.06576,0.013031,0.15052,0.23022,0,0,25,3,13,
0,-1.3392,-0.24845,-1.348,-0.70941,1,0,29,3,13,
1,-0.60452,0.34429,-0.97002,-0.10538,1,0,31,3,13,
0,-0.39351,-0.061919,0.16847,-0.09468,1,0,34,3,13,
0,0.50058,0.30166,0.56949,0.15476,0,0,35,3,13,
1,0.041403,0.22903,-0.055926,0.015448,1,0,37,4,13,
1,-0.86426,0.11682,5.911e-05,-0.014171,0,0,40,4,13,
0,0.99469,0.046619,-1.4327,-0.31103,1,1,41,4,13,
0,0.93533,0.62041,0.30562,0.49895,1,0,42,4,13,
0,-0.051272,0.63954,0.28456,0.53736,0,0,43,4,13,
1,0.51215,0.47035,-0.20416,-0.23171,0,0,46,4,13,
1,0.64486,0.06324,0.091829,0.093011,0,0,48,4,13), ncol=10, byrow=TRUE)

corrgram(mat, order=TRUE,lower.panel=function(x,y,...) panel.conf(x,y))
